// Minecraft Standalone Client
// Copyright (C) 2009-2010 Colin Bartolome
// Licensed under the GPL. See LICENSE.txt for details.

import java.io.*;
import java.net.*;

import javax.swing.*;

public class ServerDialog extends JDialog
{
   private static final String[] PARAMETERS = new String[]
   {
      "username",
      "sessionid",
      "loadmap_user",
      "loadmap_id",
      "server",
      "port",
      "mppass"
   };
   
   public ServerDialog(final Main main, final MainApplet applet)
   {
      goForIt(main, applet);
   }
   
   private void goForIt(Main main, MainApplet applet)
   {
      try
      {
         parseParameters(applet, getPage("http://www.minecraft.net/indev/", main.getLoginCookie()));
      
         setVisible(false);
      }
      catch (IOException ioe)
      {
         JOptionPane.showMessageDialog(ServerDialog.this, "Could not parse the necessary parameters. Is the URL right?");
      }
   }

   private String getPage(String url, String loginCookie) throws IOException
   {
      StringBuilder rtn = new StringBuilder();
      URLConnection connection = new URL(url).openConnection();
      
      connection.addRequestProperty("Cookie", "_lgn=" + loginCookie);
      connection.setDoInput(true);
      connection.connect();
      
      BufferedReader in = new BufferedReader(new InputStreamReader(connection.getInputStream()));
      char[] buffer = new char[4096];
      int charsRead;
      
      while ((charsRead = in.read(buffer)) != -1)
         rtn.append(buffer, 0, charsRead);
      
      in.close();
      
      return rtn.toString();
   }
   
   private void parseParameters(MainApplet applet, String text)
   {
      for (String parameter : PARAMETERS)
      {
         int index = text.indexOf("name=\"" + parameter + "\"");
         
         if (index != -1)
         {
            index = text.indexOf("value=\"", index) + "value=\"".length();
            
            String value = text.substring(index, text.indexOf("\"", index));
            
            System.out.println(parameter + ": " + value);
            
            applet.putParameter(parameter, value);
         }
      }
   }
}
