// Minecraft Standalone Client
// Copyright (C) 2009-2010 Colin Bartolome
// Licensed under the GPL. See LICENSE.txt for details.

import java.io.*;
import java.net.*;

import javax.swing.*;

public class UpdateDialog extends JDialog implements Runnable
{
   private File localFile;
   
   private URLConnection connection;
   
   public UpdateDialog(Main main)
   {
      super(main, "Downloading Update", true);
      
      JPanel panel = new JPanel();
      
      panel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
      panel.add(new JLabel("Downloading update. Please wait."));
      add(panel);
      pack();
      setLocationRelativeTo(main);
      setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
      
      try
      {
         File dummy = new File("com");
         URL remote = new URL("http://www.minecraft.net/indev/client/minecraft.jar");
         
         connection = remote.openConnection();
         connection.setDoOutput(false);
         connection.setDoInput(true);
         
         localFile = new File("lib/minecraft.jar");

         if (dummy.exists() || !localFile.exists() || localFile.lastModified() < connection.getLastModified())
         {
            new Thread(this, "Downloader").start();
            setVisible(true);
            
            if (dummy.exists())
               deleteDirectory(dummy);
            
            JOptionPane.showMessageDialog(this, "The application will now quit. It should pick up the updated applet version when restarted.");
            System.exit(0);
         }
      }
      catch (IOException ioe)
      {
         System.err.println("Error checking for latest JAR version: " + ioe.toString());
      }
   }
   
   @Override
   public void run()
   {
      try
      {
         InputStream in = connection.getInputStream();
         FileOutputStream out = new FileOutputStream(localFile);
         int bytesRead;
         byte[] buffer = new byte[4096];
         
         while ((bytesRead = in.read(buffer)) != -1)
            out.write(buffer, 0, bytesRead);
         
         in.close();
         out.close();
      }
      catch (IOException ioe)
      {
         System.err.println("Error downloading latest JAR version: " + ioe.toString());
      }
      
      SwingUtilities.invokeLater(new Runnable()
      {
         @Override
         public void run()
         {
            setVisible(false);
         }
      });
   }
   
   private void deleteDirectory(File root) throws IOException
   {
      for (File file : root.listFiles())
         if (file.isDirectory())
            deleteDirectory(file);
         else
            file.delete();
      
      root.delete();
   }
}
